<?php
/**
 * Apptha
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the EULA
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.apptha.com/LICENSE.txt
 *
 * ==============================================================
 *                 MAGENTO EDITION USAGE NOTICE
 * ==============================================================
 * This package designed for Magento COMMUNITY edition
 * Apptha does not guarantee correct work of this extension
 * on any other Magento edition except Magento COMMUNITY edition.
 * Apptha does not provide extension support in case of
 * incorrect edition usage.
 * ==============================================================
 *
 * @category    Apptha
 * @package     Apptha_Marketplace
 * @version     1.9.0
 * @author      Apptha Team <developers@contus.in>
 * @copyright   Copyright (c) 2015 Apptha. (http://www.apptha.com)
 * @license     http://www.apptha.com/LICENSE.txt
 * 
 */
/**
 * Function written in this file are globally accessed
 */
class Apptha_Marketplace_Helper_Marketplace extends Mage_Core_Helper_Abstract {
    
    /**
     * Function to get the seller rewrite url
     *
     * Passed the seller id to rewrite the particular seller url
     *
     * @param int $sellerId
     *            This function will return the rewrited url for a particular seller
     * @return string
     */
    
   
    
    public function getSellerRewriteUrl($sellerId) {
    /** getting seller id */
        $targetPath = 'marketplace/seller/displayseller/id/' . $sellerId;
        $mainUrlRewrite = Mage::getModel ( 'core/url_rewrite' )->load ( $targetPath, 'target_path' );
        $getRequestPath = $mainUrlRewrite->getRequestPath ();
        return Mage::getUrl ( $getRequestPath );
    }
    
    /**
     * Function to load particular seller information
     *
     * In this function seller id is passed to get particular seller data
     *
     * @param int $_id
     *            This function will return the particular seller information as array
     * @return array
     */
    public function getSellerCollection($_id) {
    /** load collection based on seller id */
        return Mage::getModel ( 'marketplace/sellerprofile' )->load ( $_id, 'seller_id' );
    }
    
    /**
     * Function to load particular category information
     *
     * Passed Category Id to get the category information
     *
     * @param int $catId
     *            This function will return the Category information as array
     * @return array
     */
    public function getCategoryData($catId) {
    /** load category based on category id */
        return Mage::getModel ( 'catalog/category' )->load ( $catId );
    }
    
    /**
     * Function to delete product
     *
     * Product entity id are passed to delete the product
     *
     * @param int $entityIds
     *            This function will return true or false
     * @return bool
     */
    public function deleteProduct($entityIds) {
        $productSellerId = Mage::getModel ( 'catalog/product' )->load ( $entityIds )->getSellerId ();
        if ($productSellerId == Mage::getSingleton ( 'customer/session' )->getCustomerId ()) {
            Mage::helper ( 'marketplace/general' )->changeAssignProductId ( $entityIds );
            Mage::getModel ( 'catalog/product' )->setId ( $entityIds )->delete ();
        }
        return true;
    }
    
    /**
     * Function to get product collection
     *
     * Product id is passed to get the particular product information
     *
     * @param int $getProductId
     *            This function will display the particular product information as array
     * @return array
     */
    public function getProductInfo($getProductId) {
        return Mage::getModel ( 'catalog/product' )->load ( $getProductId );
    }
    
    /**
     * Function to load email template
     *
     * Passed the template id to load the email template
     *
     * @param int $templateId
     *            This function will return the email template
     * @return string
     */
    public function loadEmailTemplate($templateId) {
        return Mage::getModel ( 'core/email_template' )->load ( $templateId );
    }
    
    /**
     * Function to load customer data
     *
     * Passed the selle id to load a particular seller details
     *
     * @param int $sellerId
     *            This function will return the seller details as array
     * @return array
     */
    public function loadCustomerData($sellerId) {
    /** To load customer based on seller id */
        return Mage::getModel ( 'customer/customer' )->load ( $sellerId );
    }
    
    /**
     * Function to storing downloadable product link data
     *
     * Downloadable file data are passed as array
     *
     * @param array $linkModel
     *            This function will return true or false
     * @return bool
     */
    public function saveDownLoadLink($linkModel) {
    /** to save download link */
        $linkModel->save ();
        return true;
    }
    
    /**
     * Function to set product instock
     *
     * Passed the Product is instock or not value
     *
     * @param int $isInStock
     *            This function will return 0 or 1
     * @return bool
     */
    public function productInStock($isInStock) {
        if (isset ( $isInStock )) {
            return $stock_data ['is_in_stock'] = $isInStock;
        } else {
            return $stock_data ['is_in_stock'] = 1;
        }
    }

    
    /**
     * Retrieve attribute id for seller shipping
     *
     * This function will return the seller shipping id
     *
     * @return int
     */
    public function getSellerShipping() {
        return Mage::getResourceModel ( 'eav/entity_attribute' )->getIdByCode ( 'catalog_product', 'seller_shipping_option' );
    }
    /**
     * Load particular product info
     *
     * @param Mage_Catalog_Model_Product $product            
     */
    protected function _loadProduct(Mage_Catalog_Model_Product $product) {
        $product->load ( $product->getId () );
    }
    /**
     * Get the New and Sale Label for a particular product
     *
     * @param Mage_Catalog_Model_Product $product            
     * @return string
     */
    public function getLabel(Mage_Catalog_Model_Product $product) {
        $html = '';
        $this->_loadProduct ( $product );
        if ($this->_isNew ( $product )) {
            $html .= '<div class="new-label new-right' . '">New</div>';
        }
        if ($this->_isOnSale ( $product )) {
            $html .= '<div class="sale-label sale-left">Sale</div>';
        }
        return $html;
    }
    /**
     * Checking the from and to date for new and sale product
     *
     * @param unknown $from            
     * @param unknown $to            
     * @return boolean
     */
    protected function _checkDate($from, $to) {
        $return = true;
        $date = date( 'Y-m-d');
        $today = strtotime ($date);
        if ($from && $today < $from) {
            $return = false;
        }
        if ($to && $today > $to) {
            $return = false;
        }
        if (! $to && ! $from) {
            $return = false;
        }
        return $return;
    }
    /**
     * Check whether a product is set as new
     *
     * @param unknown $product            
     */
    protected function _isNew($product) {
        $from = strtotime ( $product->getData ( 'news_from_date' ) );
        $to = strtotime ( $product->getData ( 'news_to_date' ) );
        return $this->_checkDate ( $from, $to );
    }
    /**
     * check whether a product is set for sale
     *
     * @param unknown $product            
     */
    protected function _isOnSale($product) {
        $from = strtotime ( $product->getData ( 'special_from_date' ) );
        $to = strtotime ( $product->getData ( 'special_to_date' ) );
        return $this->_checkDate ( $from, $to );
    }
 
    /**
     * Resize category images to display
     *
     * Return image url
     *
     * @return string
     */
    public function getResizedImage($imagePath, $width, $height = null, $quality = 100) {
        
        $return = '';
        $imageUrl = Mage::getBaseDir ( 'media' ) . DS . 'catalog' . DS . "category" . DS . $imagePath;
        
        if (! $imagePath || ! is_file ( $imageUrl )) {
            $return = false;
        } else {
            /**
             * Because clean Image cache function works in this folder only
             */
            $imageResized = Mage::getBaseDir ( 'media' ) . DS . 'catalog' . DS . 'product' . DS . "cache" . DS . "cat_resized" . DS . $width . $imagePath;
            if (! file_exists ( $imageResized ) && file_exists ( $imageUrl ) || file_exists ( $imageUrl ) && filemtime ( $imageUrl ) > filemtime ( $imageResized )) :
                $imageObj = new Varien_Image ( $imageUrl );
                $imageObj->constrainOnly ( true );
                $imageObj->keepAspectRatio ( false );
                $imageObj->keepFrame ( false );
                $imageObj->quality ( $quality );
                $imageObj->resize ( $width, $height );
                $imageObj->save ( $imageResized );
            
   
endif;
            
            if (file_exists ( $imageResized )) {
                $return = Mage::getBaseUrl ( 'media' ) . "catalog/product/cache/cat_resized/" . $width . $imagePath;
            } else {
                $return = $imagePath;
            }
        }
        return $return;
    
    }
    
    /**
     * Function to get the dashboard url
     *
     * This Function will return the redirect url to dashboard
     *
     * @return string
     */
    public function dashboardUrl() {
    return Mage::getUrl ( 'marketplace/seller/dashboard' );
    } 
    
    /**
     * Function to get the received amount of seller
     *
     * This funtion will return the Total amount received by the seller from admin
     * @return int
     */
    public function getAmountReceived() {
        $returnContent = "";
        $getSellerId = Mage::getSingleton('customer/session')->getCustomer()->getId();
        $transactionCollection = Mage::getModel('marketplace/transaction')->getCollection()
        ->addFieldToSelect('seller_commission')->addFieldToFilter('seller_id', $getSellerId)->addFieldToFilter('paid', 1);
        $transactionCollection->getSelect()->columns('SUM(seller_commission) AS seller_commission')->group('seller_id');
        foreach ($transactionCollection as $amounts) {
        $returnContent = $amounts->getSellerCommission();
        }
        $collectionPaidUpto = Mage::getModel('marketplace/transaction')->getCollection()->addFieldToSelect('paid_upto')->addFieldToFilter('seller_id', $getSellerId)->addFieldToFilter('paid', 0);
        $collectionPaidUpto->getSelect()->columns('SUM(paid_upto) AS paid_upto')->group('seller_id');
         foreach ($collectionPaidUpto as $amountKey)  {
        $returnContent = $returnContent + $amountKey->getPaidUpto();
        }
        return Mage::helper('core')->currency($returnContent, true, false);
    }
    
    /**
     * Function to get the remaining amount of seller
     *
     * This funtion will return the Total remaining amount by admin to seller
     * @return int
     */
    public function getAmountRemaining() {
        $paidUpto = null;
         $return = '';
         $sellerId = Mage::getSingleton('customer/session')->getCustomer()->getId();
        $_collection = Mage::getModel('marketplace/transaction')->getCollection()
        ->addFieldToSelect('seller_commission')
        ->addFieldToFilter('seller_id', $sellerId)
        ->addFieldToFilter('paid', 0);
        $_collection->getSelect()
        ->columns('SUM(seller_commission) AS seller_commission')
        ->group('seller_id');
        foreach ($_collection as $amount) {
         $return = $amount->getSellerCommission();
         }
    
         $collectionPaidUpto = Mage::getModel('marketplace/transaction')->getCollection()
         ->addFieldToSelect('paid_upto')
         ->addFieldToFilter('seller_id', $sellerId)
         ->addFieldToFilter('paid', 0);
        $collectionPaidUpto->getSelect()
         ->columns('SUM(paid_upto) AS paid_upto')
         ->group('seller_id');
         foreach ($collectionPaidUpto as $amount) {
         $paidUpto = $amount->getPaidUpto();
         }
         $return = $return - $paidUpto;
            return Mage::helper('core')->currency($return, true, false);
    }
    
    /**
     * Function to update comment from admin
     *
     * Passed the comment provided by admin before pay amount to seller
     * @param int $comment
     *
     * Passed the transaction id to update the comment for that particular transaction
     * @param int $transactionId
     *
     * This function will return true or false
     * @return bool
     */
    public function updateComment($comment, $transactionId,$amount,$paid) {
        $now = Mage::getModel('core/date')->date('Y-m-d H:i:s', time());
        if (!empty($transactionId)) {
        
        Mage::getModel('marketplace/transaction')
        ->setComment($comment)
        ->setPaidDate($now)
        ->setPaidUpto($amount)
        ->setPaid($paid)
        ->setId($transactionId)->save();
        return true;
         }
    }
    
    /**
     * Get subcribed date
     * Passed seller id to get the seller customer registered date
     *
     * @param $sellerId Return
     *        	subscribed date
     * @return date
     */
    public function subscribedDate($sellerId) {
    	/**
    	 * get seller/designer subscribed date
    	 */
    	$collection = Mage::getModel ( 'marketplace/subscribedinfo' )->load ( $sellerId, 'seller_id' );
    	if ($collection) {
    		$subscribedDate = date ( "jS F Y", strtotime ( $collection->getPaidDate () ) );
    		return $subscribedDate;
    	}
    }
    /**
     * Get registered expire date
     * Passed seller id to get the seller customer registered date
     *
     * @param $sellerId Return
     * registered trial expire date
     * @return date
     */
    public function subscriptionEndDate($sellerId) {
    	$subscribed = Mage::getModel ( 'marketplace/subscribedinfo' )->load ( $sellerId, 'seller_id' );
    	if ($subscribed->getId ()) {
    		$subscriptionStartDate = $subscribed->getPaidDate ();
    		$planId = $subscribed->getPlanId ();
    		$getPlanInfo = Mage::getModel ( 'marketplace/subscriptionplans' )->load ( $planId, 'plan_id' );
    		$subscriptionPeriod = $getPlanInfo->getSubscriptionPeriod ();
    		$validityPeriod = $getPlanInfo->getValidityPeriod ();
    		if ($getPlanInfo->getOfferPeriod () != '' && $getPlanInfo->getOfferValidityPeriod () != '') {
    			$offerPeriod = $getPlanInfo->getOfferPeriod ();
    			$offerValidityPeriod = $getPlanInfo->getOfferValidityPeriod ();
    		}
    		if ($subscriptionPeriod == 1 && $offerPeriod == 1) {
    			$subscriptionEndDate = date ( 'Y-m-d', strtotime ( '+' . $validityPeriod + $offerValidityPeriod . ' months', strtotime ( $subscriptionStartDate ) ) );
    		} elseif ($subscriptionPeriod == 2 && $offerPeriod == 2) {
    			$subscriptionEndDate = date ( 'Y-m-d', strtotime ( '+' . $validityPeriod + $offerValidityPeriod . ' years', strtotime ( $subscriptionStartDate ) ) );
    		} elseif ($subscriptionPeriod == 1 && $offerPeriod == 2) {
    			$subscriptionEndDate = date ( 'Y-m-d', strtotime ( '+' . $offerValidityPeriod . ' years ' . $validityPeriod . ' months', strtotime ( $subscriptionStartDate ) ) );
    		} elseif ($subscriptionPeriod == 2 && $offerPeriod == 1) {
    			$subscriptionEndDate = date ( 'Y-m-d', strtotime ( '+' . $validityPeriod . ' years ' . $offerValidityPeriod . ' months', strtotime ( $subscriptionStartDate ) ) );
    		} elseif ($subscriptionPeriod == 2 && $offerPeriod == 0) {
    			$subscriptionEndDate = date ( 'Y-m-d', strtotime ( '+' . $validityPeriod . ' years ', strtotime ( $subscriptionStartDate ) ) );
    		} elseif ($subscriptionPeriod == 1 && $offerPeriod == 0) {
    			$subscriptionEndDate = date ( 'Y-m-d', strtotime ( '+' . $validityPeriod . ' months', strtotime ( $subscriptionStartDate ) ) );
    		}
    	}
    	return $subscriptionEndDate;
    }
    
    public function outofstock($productId){
    	$assignProducts = Mage::getResourceModel('catalog/product_collection')
    	->addAttributeToSelect(array('name'))
    	->addAttributeToFilter('assign_product_id', $productId)
    	->load();
    	
    	return count($assignProducts);
    }
    
    /**
     * Seller added product count
     *
     *  Passed seller id to the product collection
     *  @param $sellerId
     *
     *  return the number of products
     *  @return int;
     */
    public function getProductCount($sellerId){
    	$product = Mage::getModel('catalog/product')->getCollection()
    	->addAttributeToFilter('seller_id',$sellerId);
    	$addedProducts = count($product);
    	return $addedProducts;
    }

}